Asset
------------------------------
The Asset model holds asset specific data for each real asset, facility (plant, infrastructure etc) that is part of a Project (which may or may not be financed)

The assumption is that an Asset participates in only one Project at a time (if linked to a project object)


.. automodule:: portfolio.Asset
   :members:
   :undoc-members:
   :noindex:

   .. automethod:: portfolio.Asset.Asset